@@ -330,7 +330,8 @@ of the calculated field is stored in a directly following SXFormula record. If f
 	d (4, gsf_mem_dump (q->data + 2, MIN (q->length, 0xc)););
 
 	/* SQL type of field (ignored) */
-	if (ms_biff_query_peek_next (q, &opcode) && opcode == BIFF_SXFDBTYPE && check_next (q, 2)) ;
+	if (ms_biff_query_peek_next (q, &opcode) && opcode == BIFF_SXFDBTYPE && check_next (q, 2))
+		/* Nothing */ ;
 
 	switch (index_type) {
 	case 1 :
@@ -387,8 +388,8 @@ xls_read_pivot_cache (XLSReadPivot *s, BiffQuery *q)
 		guint16 base_fields	= GSF_LE_GET_GUINT16 (q->data + 10);	/* base */
 		/* guint16 zero */
 		guint16 type		= GSF_LE_GET_GUINT16 (q->data + 16);
-		g_printerr ("num_rec = %u;\nstream_id = %hu;\n"
-			 "rec per block = %hu;\nbase fields = %hu;\ntotal fields = %hu;\n"
+		g_printerr ("num_rec = %u;\nstream_id = %u;\n"
+			 "rec per block = %u;\nbase fields = %hu;\ntotal fields = %hu;\n"
 			 "last modified by = '%s';type = 0x%x, flags = 0x%x;\n",
 			 num_records, stream_id, rec_per_block, base_fields,
 			 num_fields, refreshedBy, type, flags);
