@@ -117,11 +117,13 @@ static GHashTable *bisection_vlookup_string_cache;
 static GHashTable *bisection_vlookup_float_cache;
 static GHashTable *bisection_vlookup_bool_cache;
 static size_t total_cache_size;
+static size_t protect_string_pool;
+static size_t protect_float_pool;
 
 static void
 clear_caches (void)
 {
-	if (!lookup_string_pool)
+	if (!linear_hlookup_string_cache)
 		return;
 
 	if (debug_lookup_caches)
@@ -175,27 +177,33 @@ clear_caches (void)
 
 	/* ---------- */
 
-	g_string_chunk_free (lookup_string_pool);
-	lookup_string_pool = NULL;
+	if (!protect_string_pool) {
+		g_string_chunk_free (lookup_string_pool);
+		lookup_string_pool = NULL;
+	}
 
-	go_mem_chunk_destroy (lookup_float_pool, TRUE);
-	lookup_float_pool = NULL;
+	if (!protect_float_pool) {
+		go_mem_chunk_destroy (lookup_float_pool, TRUE);
+		lookup_float_pool = NULL;
+	}
 }
 
 static void
 create_caches (void)
 {
-	if (lookup_string_pool)
+	if (linear_hlookup_string_cache)
 		return;
 
 	total_cache_size = 0;
 
-	lookup_string_pool = g_string_chunk_new (100 * 1024);
+	if (!lookup_string_pool)
+		lookup_string_pool = g_string_chunk_new (100 * 1024);
 
-	lookup_float_pool =
-		go_mem_chunk_new ("lookup float pool",
-				  sizeof (gnm_float),
-				  sizeof (gnm_float) * 1000);
+	if (!lookup_float_pool)
+		lookup_float_pool =
+			go_mem_chunk_new ("lookup float pool",
+					  sizeof (gnm_float),
+					  sizeof (gnm_float) * 1000);
 
 	linear_hlookup_string_cache = g_hash_table_new_full
 		((GHashFunc)value_hash,
@@ -361,37 +369,54 @@ get_linear_lookup_cache (GnmFuncEvalInfo *ei,
 static void
 linear_lookup_cache_commit (LinearLookupInfo *pinfo)
 {
+	/*
+	 * It is possible to have an entry for the key already in the
+	 * cache.  In that case we fail to deduct from total_cache_size
+	 * but it really doesn't matter.
+	 */
+	total_cache_size += g_hash_table_size (pinfo->h);
+
 	g_hash_table_replace (*pinfo->cache, pinfo->key_copy, pinfo->h);
 }
 
+/*
+ * We use an extra level of pointers for "cache" here to avoid problems
+ * in the case where we later prune the caches.  The pointer to the
+ * GHashTable* will stay valid.
+ */
+typedef struct {
+	gboolean is_new;
+	GnmValue *key_copy;
+	GHashTable **cache;
+	LookupBisectionCacheItem *item;
+} BisectionLookupInfo;
+
 static LookupBisectionCacheItem *
 get_bisection_lookup_cache (GnmFuncEvalInfo *ei,
 			    GnmValue const *data, GnmValueType datatype,
-			    gboolean vertical, gboolean *brand_new)
+			    gboolean vertical, BisectionLookupInfo *pinfo)
 {
 	GnmValue const *key;
-	GnmValue *key_copy = NULL;
-	GHashTable **cache;
-	LookupBisectionCacheItem *h;
 
-	*brand_new = FALSE;
+	pinfo->is_new = FALSE;
+	pinfo->key_copy = NULL;
 
 	create_caches ();
 
 	/* The "&" here is for the pruning case.  */
 	switch (datatype) {
 	case VALUE_STRING:
-		cache = vertical
+		pinfo->cache = vertical
 			? &bisection_vlookup_string_cache
 			: &bisection_hlookup_string_cache;
 		break;
 	case VALUE_FLOAT:
-		cache = vertical
+		pinfo->cache = vertical
 			? &bisection_vlookup_float_cache
 			: &bisection_hlookup_float_cache;
 		break;
 	case VALUE_BOOLEAN:
-		cache = vertical
+		pinfo->cache = vertical
 			? &bisection_vlookup_bool_cache
 			: &bisection_hlookup_bool_cache;
 		break;
@@ -410,7 +435,7 @@ get_bisection_lookup_cache (GnmFuncEvalInfo *ei,
 		if (sr.sheet != end_sheet)
 			return NULL; /* 3D */
 
-		key = key_copy = value_new_cellrange_r (sr.sheet, &sr.range);
+		key = pinfo->key_copy = value_new_cellrange_r (sr.sheet, &sr.range);
 		break;
 	}
 	case VALUE_ARRAY:
@@ -420,19 +445,35 @@ get_bisection_lookup_cache (GnmFuncEvalInfo *ei,
 		return NULL;
 	}
 
-	h = g_hash_table_lookup (*cache, key);
-	if (h == NULL) {
+	pinfo->item = g_hash_table_lookup (*pinfo->cache, key);
+	if (pinfo->item == NULL) {
 		prune_caches ();
-		*brand_new = TRUE;
-		h = g_new0 (LookupBisectionCacheItem, 1);
-		if (!key_copy) key_copy = value_dup (key);
-		g_hash_table_insert (*cache, key_copy, h);
-	} else
-		value_release (key_copy);
+		pinfo->is_new = TRUE;
+		pinfo->item = g_new0 (LookupBisectionCacheItem, 1);
+		if (!pinfo->key_copy)
+			pinfo->key_copy = value_dup (key);
+	} else {
+		value_release (pinfo->key_copy);
+		pinfo->key_copy = NULL;
+	}
 
-	return h;
+	return pinfo->item;
 }
 
+static void
+bisection_lookup_cache_commit (BisectionLookupInfo *pinfo)
+{
+	/*
+	 * It is possible to have an entry for the key already in the
+	 * cache.  In that case we fail to deduct from total_cache_size
+	 * but it really doesn't matter.
+	 */
+	total_cache_size += pinfo->item->n;
+
+	g_hash_table_replace (*pinfo->cache, pinfo->key_copy, pinfo->item);
+}
+
+
 /* -------------------------------------------------------------------------- */
 
 static gboolean
@@ -512,6 +553,8 @@ find_index_linear_equal_string (GnmFuncEvalInfo *ei,
 	if (info.is_new) {
 		int lp, length = calc_length (data, ei->pos, vertical);
 
+		protect_string_pool++;
+
 		for (lp = 0; lp < length; lp++) {
 			GnmValue const *v = get_elem (data, lp, ei->pos, vertical);
 			char *vc;
@@ -523,13 +566,14 @@ find_index_linear_equal_string (GnmFuncEvalInfo *ei,
 			if (!g_hash_table_lookup_extended (h, vc, NULL, NULL)) {
 				char *sc = g_string_chunk_insert (lookup_string_pool, vc);
 				g_hash_table_insert (h, sc, GINT_TO_POINTER (lp));
-				total_cache_size++;
 			}
 
 			g_free (vc);
 		}
 
 		linear_lookup_cache_commit (&info);
+
+		protect_string_pool--;
 	}
 
 	sc = g_utf8_casefold (value_peek_string (find), -1);
@@ -559,6 +603,8 @@ find_index_linear_equal_float (GnmFuncEvalInfo *ei,
 	if (info.is_new) {
 		int lp, length = calc_length (data, ei->pos, vertical);
 
+		protect_float_pool++;
+
 		for (lp = 0; lp < length; lp++) {
 			GnmValue const *v = get_elem (data, lp, ei->pos, vertical);
 			gnm_float f2;
@@ -572,11 +618,12 @@ find_index_linear_equal_float (GnmFuncEvalInfo *ei,
 				gnm_float *fp = go_mem_chunk_alloc (lookup_float_pool);
 				*fp = f2;
 				g_hash_table_insert (h, fp, GINT_TO_POINTER (lp));
-				total_cache_size++;
 			}
 		}
 
 		linear_lookup_cache_commit (&info);
+
+		protect_float_pool--;
 	}
 
 	f = value_get_as_float (find);
@@ -635,25 +682,28 @@ find_index_bisection (GnmFuncEvalInfo *ei,
 		      gint type, gboolean vertical)
 {
 	int high, low, lastlow, res;
-	gboolean brand_new;
 	LookupBisectionCacheItem *bc;
 	gboolean stringp;
 	int (*comparer) (const void *,const void *);
 	LookupBisectionCacheItemElem key;
+	BisectionLookupInfo info;
 
 	bc = get_bisection_lookup_cache (ei, data, find->type, vertical,
-					 &brand_new);
+					 &info);
 	if (!bc)
 		return LOOKUP_DATA_ERROR;
 
 	stringp = (find->type == VALUE_STRING);
 	comparer = stringp ? bisection_compare_string : bisection_compare_float;
 
-	if (brand_new) {
+	if (info.is_new) {
 		int lp, length = calc_length (data, ei->pos, vertical);
 
 		bc->data = g_new (LookupBisectionCacheItemElem, length + 1);
 
+		if (stringp)
+			protect_string_pool++;
+
 		for (lp = 0; lp < length; lp++) {
 			GnmValue const *v = get_elem (data, lp, ei->pos, vertical);
 			if (!find_compare_type_valid (find, v))
@@ -673,7 +723,10 @@ find_index_bisection (GnmFuncEvalInfo *ei,
 		bc->data = g_renew (LookupBisectionCacheItemElem,
 				    bc->data,
 				    bc->n);
-		total_cache_size += bc->n;
+		bisection_lookup_cache_commit (&info);
+
+		if (stringp)
+			protect_string_pool--;
 	}
 
 #ifdef DEBUG_BISECTION
@@ -1994,7 +2047,17 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 G_MODULE_EXPORT void
 go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
-	clear_caches ();
 	g_signal_handlers_disconnect_by_func (gnm_app_get_app (),
 					      G_CALLBACK (clear_caches), NULL);
+
+	if (protect_string_pool) {
+		g_printerr ("Imbalance in string pool: %d\n", (int)protect_string_pool);
+		protect_string_pool = 0;
+	}
+	if (protect_float_pool) {
+		g_printerr ("Imbalance in float pool: %d\n", (int)protect_float_pool);
+		protect_float_pool = 0;
+	}
+
+	clear_caches ();
 }
