@@ -151,6 +151,8 @@ typedef struct _FormatState {
 	} align;
 	struct {
 		GOFontSel	*selector;
+		GtkWidget       *underline_picker;
+		GnmUnderline     underline;
 	} font;
 	struct {
 		GocCanvas	*canvas;
@@ -756,8 +758,8 @@ cb_font_changed (G_GNUC_UNUSED GtkWidget *widget,
 
 	attr = pango_attr_iterator_get (aiter, PANGO_ATTR_UNDERLINE);
 	if (attr) {
-		int i = ((PangoAttrInt*)attr)->value;
-		GnmUnderline u = gnm_translate_underline_from_pango (i);
+		/* Underline is special: we go beyond what pango has */
+		GnmUnderline u = state->font.underline;
 		if (!gnm_style_is_element_set (res, MSTYLE_FONT_UNDERLINE) ||
 		    u != gnm_style_get_font_uline (res)) {
 			changed = TRUE;
@@ -827,10 +829,27 @@ change_font_attr (FormatState *state, PangoAttribute *attr)
 }
 
 static void
-set_font_underline (FormatState *state, GnmUnderline u)
+set_font_underline (FormatState *state, GnmUnderline uline)
 {
-	PangoUnderline pu = gnm_translate_underline_to_pango (u);
-	change_font_attr (state, pango_attr_underline_new (pu));
+	PangoUnderline pu = gnm_translate_underline_to_pango (uline);
+	GOOptionMenu *om = GO_OPTION_MENU (state->font.underline_picker);
+	GtkMenuShell *ms = GTK_MENU_SHELL (go_option_menu_get_menu (om));
+	GList *children, *l;
+
+	if (uline != state->font.underline) {
+		state->font.underline = uline;
+		change_font_attr (state, pango_attr_underline_new (pu));
+	}
+
+	children = gtk_container_get_children (GTK_CONTAINER (ms));
+	for (l = children; l; l = l->next) {
+		GtkMenuItem *item = GTK_MENU_ITEM (l->data);
+		GnmUnderline u = GPOINTER_TO_INT
+			(g_object_get_data (G_OBJECT (item), "value"));
+		if (u == uline)
+			go_option_menu_select_item (om, item);
+	}
+	g_list_free (children);
 }
 
 static void
@@ -861,7 +880,7 @@ fmt_dialog_init_font_page (FormatState *state)
 	GnmColor *def_sc;
 	GtkWidget *up;
 
-	up = go_option_menu_build
+	up = state->font.underline_picker = go_option_menu_build
 		(C_("underline", "None"), UNDERLINE_NONE,
 		 C_("underline", "Single"), UNDERLINE_SINGLE,
 		 C_("underline", "Double"), UNDERLINE_DOUBLE,
@@ -925,6 +944,7 @@ fmt_dialog_init_font_page (FormatState *state)
 				      pts * PANGO_SCALE);
 	}
 
+	state->font.underline = UNDERLINE_NONE;
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_UNDERLINE))) {
 		GnmUnderline ut = gnm_style_get_font_uline (state->style);
 		set_font_underline (state, ut);
@@ -1070,8 +1090,7 @@ static struct
 	double const			points[4];
 	int const			states;
 	GnmStyleBorderLocation	const	location;
-} const line_info[] =
-{
+} const line_info[] = {
 	/*
 	  state 1 = single cell;
 	  state 2 = multi vert, single horiz (A1:A2);
@@ -1195,13 +1214,8 @@ border_event (GtkWidget *widget, GdkEventButton *event, FormatState *state)
 {
 	double x = event->x;
 	double y = event->y;
-	BorderPicker		*edge;
-
-	/* Crap!  This variable is always initialized.
-	 * However, the compiler is confused and thinks it is not
-	 * so we are forced to pick a random irrelevant value.
-	 */
-	GnmStyleBorderLocation	 which = GNM_STYLE_BORDER_LEFT;
+	BorderPicker *edge;
+	GnmStyleBorderLocation which;
 
 	if (event->button != 1)
 		return FALSE;
@@ -1272,6 +1286,7 @@ border_event (GtkWidget *widget, GdkEventButton *event, FormatState *state)
 			break;
 
 		default:
+			which = GNM_STYLE_BORDER_LEFT;
 			g_assert_not_reached ();
 		}
 
@@ -1385,14 +1400,14 @@ draw_border_preview (FormatState *state)
 	}
 
 	for (i = 0; i < GNM_STYLE_BORDER_EDGE_MAX; ++i) {
-		BorderPicker *border = &state->border.edge[i];
-		void (*func)(GocItem *item) = border->is_selected
-			? &goc_item_show : &goc_item_hide;
+		BorderPicker const *border = &state->border.edge[i];
+		int j;
 
 		for (j = 0; line_info[j].states != 0 ; ++j) {
 			if ((int)line_info[j].location == i &&
 			    state->border.lines[j] != NULL)
-				(*func) (state->border.lines[j]);
+				goc_item_set_visible (state->border.lines[j],
+						      border->is_selected);
 		}
 	}
 
