@@ -181,6 +181,10 @@ gnm_pre_parse_init (int argc, gchar const **argv)
 	}
 #endif
 
+	/* Default value is bogus, see 732184.  */
+	if (!getenv ("G_ENABLE_DIAGNOSTIC"))
+		setenv ("G_ENABLE_DIAGNOSTIC", "0", FALSE);
+
 	/* We cannot use gnm_debug_flag yet.  See 627840.  */
 	gnm_debug = getenv ("GNM_DEBUG");
 	if (gnm_debug && strstr (gnm_debug, "gmemdebug")) {
