@@ -238,6 +238,14 @@ main (int argc, char const **argv)
 	/* No code before here, we need to init threads */
 	argv = gnm_pre_parse_init (argc, argv);
 
+	/*
+	 * Attempt to disable Ubuntu's funky, non-working scroll
+	 * bars.  This needs to be done before gtk starts loading
+	 * modules.  Note: the following call will not replace
+	 * an existing setting, so you can run with =1 if you like.
+	 */
+	g_setenv ("LIBOVERLAY_SCROLLBAR", "0", FALSE);
+
 #ifdef G_OS_WIN32
 	has_console = FALSE;
 	{
