@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
  * style-conditions.c:
  *
  * Copyright (C) 2005-2007 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2013-2014 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -36,8 +35,6 @@
 #include <func.h>
 #include <gutils.h>
 
-#define BLANKS_STRING_FOR_MATCHING " \t\n\r"
-
 typedef GObjectClass GnmStyleConditionsClass;
 struct _GnmStyleConditions {
 	GObject base;
@@ -243,7 +240,7 @@ gnm_style_cond_set_overlay (GnmStyleCond *cond, GnmStyle *overlay)
 }
 
 static GnmExpr const *
-generate_end_match (const char *endfunc, gboolean force,
+generate_end_match (const char *endfunc, gboolean force, gboolean negate,
 		    GnmExprTop const *sexpr, GnmCellRef *cr)
 {
 	GnmValue const *v = gnm_expr_get_constant (sexpr->expr);
@@ -263,12 +260,12 @@ generate_end_match (const char *endfunc, gboolean force,
 	} else
 		return NULL;
 
-	return gnm_expr_new_funcall2
-		(gnm_func_lookup_or_add_placeholder ("EXACT"),
-		 gnm_expr_new_funcall2
+	return gnm_expr_new_binary
+		(gnm_expr_new_funcall2
 		 (gnm_func_lookup_or_add_placeholder (endfunc),
 		  gnm_expr_new_cellref (cr),
 		  len_expr),
+		 negate ? GNM_EXPR_OP_NOT_EQUAL : GNM_EXPR_OP_EQUAL,
 		 gnm_expr_copy (sexpr->expr));
 }
 
@@ -318,42 +315,32 @@ gnm_style_cond_get_alternate_expr (GnmStyleCond const *cond)
 			  gnm_expr_new_cellref (&self)));
 		break;
 
-	case GNM_STYLE_COND_CONTAINS_BLANKS:
-		negate = TRUE; /* ...and fall through */
 	case GNM_STYLE_COND_NOT_CONTAINS_BLANKS:
-		/* This is imperfect.  Here we only look for space.  */
-		expr = gnm_expr_new_funcall1
-			(gnm_func_lookup_or_add_placeholder ("ISERROR"),
-			 gnm_expr_new_funcall2
-			 (gnm_func_lookup_or_add_placeholder ("FIND"),
-			  gnm_expr_new_constant (value_new_string (" ")),
-			  gnm_expr_new_cellref (&self)));
+		negate = TRUE; /* ...and fall through */
+	case GNM_STYLE_COND_CONTAINS_BLANKS:
+		/* This means blanks-only */
+
+		expr = gnm_expr_new_binary
+			(gnm_expr_new_funcall1
+			 (gnm_func_lookup_or_add_placeholder ("LEN"),
+			  gnm_expr_new_funcall1
+			  (gnm_func_lookup_or_add_placeholder ("TRIM"),
+			   gnm_expr_new_cellref (&self))),
+			 negate ? GNM_EXPR_OP_GT : GNM_EXPR_OP_EQUAL,
+			 gnm_expr_new_constant (value_new_int (0)));
+		negate = FALSE;
 		break;
 
 	case GNM_STYLE_COND_NOT_BEGINS_WITH_STR:
 		negate = TRUE; /* ...and fall through */
 	case GNM_STYLE_COND_BEGINS_WITH_STR:
-		expr = generate_end_match ("LEFT", FALSE, sexpr, &self);
-		if (expr)
-			break;
-
 		/*
-		 * We get here if sexpr is not a constant.  We are
-		 * constrained by using only Excel functions and not
-		 * evaluating the needle more than once.  The
-		 * expression used here works, but FIND is more
-		 * expensive that it ought to be.
+		 * We are constrained by using only Excel functions and not
+		 * evaluating the needle more than once.  We cannot fulfill
+		 * that and end up computing the needle twice.
 		 */
-		expr = gnm_expr_new_binary
-			(gnm_expr_new_funcall2
-			 (gnm_func_lookup_or_add_placeholder ("IFERROR"),
-			  gnm_expr_new_funcall2
-			  (gnm_func_lookup_or_add_placeholder ("FIND"),
-			   gnm_expr_copy (sexpr->expr),
-			   gnm_expr_new_cellref (&self)),
-			  gnm_expr_new_constant (value_new_int (2))),
-			 GNM_EXPR_OP_EQUAL,
-			 gnm_expr_new_constant (value_new_int (1)));
+		expr = generate_end_match ("LEFT", TRUE, negate, sexpr, &self);
+		negate = FALSE;
 		break;
 
 	case GNM_STYLE_COND_NOT_ENDS_WITH_STR:
@@ -364,7 +351,8 @@ gnm_style_cond_get_alternate_expr (GnmStyleCond const *cond)
 		 * evaluating the needle more than once.  We cannot fulfill
 		 * that and end up computing the needle twice.
 		 */
-		expr = generate_end_match ("RIGHT", TRUE, sexpr, &self);
+		expr = generate_end_match ("RIGHT", TRUE, negate, sexpr, &self);
+		negate = FALSE;
 		break;
 
 	default:
@@ -393,16 +381,17 @@ isself (GnmExpr const *expr)
 }
 
 static GnmExprTop const *
-decode_end_match (const char *endfunc, GnmExpr const *expr)
+decode_end_match (const char *endfunc, GnmExpr const *expr, gboolean *negated)
 {
 	GnmExpr const *needle;
 	GnmExpr const *expr2;
 
-	if (GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_FUNCALL &&
-	    expr->func.argc == 2 &&
-	    expr->func.func == gnm_func_lookup_or_add_placeholder ("EXACT") &&
-	    (needle = expr->func.argv[1]) &&
-	    (expr2 = expr->func.argv[0]) &&
+	*negated = (GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_NOT_EQUAL);
+
+	if ((GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_EQUAL ||
+	     GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_NOT_EQUAL) &&
+	    (needle = expr->binary.value_b) &&
+	    (expr2 = expr->binary.value_a) &&
 	    GNM_EXPR_GET_OPER (expr2) == GNM_EXPR_OP_FUNCALL &&
 	    expr2->func.argc == 2 &&
 	    expr2->func.func == gnm_func_lookup_or_add_placeholder (endfunc) &&
@@ -442,6 +431,7 @@ gnm_style_cond_canonicalize (GnmStyleCond *cond)
 	GnmExprTop const *texpr;
 	GnmValue const *v;
 	gboolean negate = FALSE;
+	gboolean match_negated;
 	GnmFunc const *iserror;
 	GnmFunc const *iferror;
 	GnmFunc const *find;
@@ -481,20 +471,29 @@ gnm_style_cond_canonicalize (GnmStyleCond *cond)
 		   GNM_EXPR_GET_OPER (expr2) == GNM_EXPR_OP_FUNCALL &&
 		   expr2->func.argc == 2 && expr2->func.func == find &&
 		   isself (expr2->func.argv[1])) {
-		GnmValue const *v =
-			gnm_expr_get_constant (expr2->func.argv[0]);
+		texpr = gnm_expr_top_new (gnm_expr_copy (expr2->func.argv[0]));
+		newop = negate
+			? GNM_STYLE_COND_CONTAINS_STR
+			: GNM_STYLE_COND_NOT_CONTAINS_STR;
+	} else if ((GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_EQUAL ||
+		    GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_GT) &&
+		   (v = gnm_expr_get_constant (expr->binary.value_b)) &&
+		   VALUE_IS_FLOAT (v) && value_get_as_float (v) == 0 &&
+		   (expr2 = expr->binary.value_a) &&
+		   GNM_EXPR_GET_OPER (expr2) == GNM_EXPR_OP_FUNCALL &&
+		   expr2->func.argc == 1 &&
+		   expr2->func.func == gnm_func_lookup_or_add_placeholder ("LEN") &&
+		   (expr2 = expr2->func.argv[0]) &&
+		   GNM_EXPR_GET_OPER (expr2) == GNM_EXPR_OP_FUNCALL &&
+		   expr2->func.argc == 1 &&
+		   expr2->func.func == gnm_func_lookup_or_add_placeholder ("TRIM") &&
+		   isself (expr2->func.argv[0])) {
+		if (GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_GT)
+			negate = !negate;
 
-		if (v && VALUE_IS_STRING (v) &&
-		    strcmp (value_peek_string (v), " ") == 0)
-			newop = negate
-				? GNM_STYLE_COND_CONTAINS_BLANKS
-				: GNM_STYLE_COND_NOT_CONTAINS_BLANKS;
-		else {
-			texpr = gnm_expr_top_new (gnm_expr_copy (expr2->func.argv[0]));
-			newop = negate
-				? GNM_STYLE_COND_CONTAINS_STR
-				: GNM_STYLE_COND_NOT_CONTAINS_STR;
-		}
+		newop = negate
+			? GNM_STYLE_COND_NOT_CONTAINS_BLANKS
+			: GNM_STYLE_COND_CONTAINS_BLANKS;
 	} else if (GNM_EXPR_GET_OPER (expr) == GNM_EXPR_OP_EQUAL &&
 		   (v = gnm_expr_get_constant (expr->binary.value_b)) &&
 		   VALUE_IS_FLOAT (v) && value_get_as_float (v) == 1 &&
@@ -511,12 +510,12 @@ gnm_style_cond_canonicalize (GnmStyleCond *cond)
 		newop = negate
 			? GNM_STYLE_COND_NOT_BEGINS_WITH_STR
 			: GNM_STYLE_COND_BEGINS_WITH_STR;
-	} else if ((texpr = decode_end_match ("LEFT", expr))) {
-		newop = negate
+	} else if ((texpr = decode_end_match ("LEFT", expr, &match_negated))) {
+		newop = (negate ^ match_negated)
 			? GNM_STYLE_COND_NOT_BEGINS_WITH_STR
 			: GNM_STYLE_COND_BEGINS_WITH_STR;
-	} else if ((texpr = decode_end_match ("RIGHT", expr))) {
-		newop = negate
+	} else if ((texpr = decode_end_match ("RIGHT", expr, &match_negated))) {
+		newop = (negate ^ match_negated)
 			? GNM_STYLE_COND_NOT_ENDS_WITH_STR
 			: GNM_STYLE_COND_ENDS_WITH_STR;
 	}
@@ -529,6 +528,29 @@ gnm_style_cond_canonicalize (GnmStyleCond *cond)
 	}
 }
 
+static gboolean
+case_insensitive_has_fix (GnmValue const *vs, GnmValue const *vp,
+			  gboolean is_prefix)
+{
+	size_t plen = g_utf8_strlen (value_peek_string (vp), -1);
+	const char *s = value_peek_string (vs);
+	size_t slen = g_utf8_strlen (s, -1);
+	GnmValue *vs2;
+	gboolean res;
+
+	if (plen > slen)
+		return FALSE;
+
+	vs2 = value_new_string_nocopy
+		(is_prefix
+		 ? g_strndup (s, g_utf8_offset_to_pointer (s, plen) - s)
+		 : g_strdup (g_utf8_offset_to_pointer (s, slen - plen)));
+	res = (value_compare (vs2, vp, FALSE) == IS_EQUAL);
+	value_release (vs2);
+
+	return res;
+}
+
 
 static gboolean
 gnm_style_cond_eval (GnmStyleCond const *cond, GnmValue const *cv,
@@ -588,33 +610,37 @@ gnm_style_cond_eval (GnmStyleCond const *cond, GnmValue const *cv,
 
 	case GNM_STYLE_COND_NOT_CONTAINS_BLANKS:
 		negate = TRUE;  /* ...and fall through */
-	case GNM_STYLE_COND_CONTAINS_BLANKS:
-		res = (cv &&
-		       strpbrk (value_peek_string (cv), BLANKS_STRING_FOR_MATCHING) != NULL);
+	case GNM_STYLE_COND_CONTAINS_BLANKS: {
+		const char *s = cv ? value_peek_string (cv) : "";
+		while (*s) {
+			gunichar uc = g_utf8_get_char (s);
+			if (!g_unichar_isspace (uc))
+				break;
+			s = g_utf8_next_char (s);
+		}
+		res = (*s == 0);
 		break;
+	}
 
 	case GNM_STYLE_COND_NOT_CONTAINS_STR:
 		negate = TRUE;  /* ...and fall through */
 	case GNM_STYLE_COND_CONTAINS_STR:
 		res = (cv &&
-		       strstr (value_peek_string (cv),
-			       value_peek_string (val0)) != NULL);
+		       gnm_excel_search_impl (value_peek_string (val0),
+					      value_peek_string (cv),
+					      0) >= 0);
 		break;
 
 	case GNM_STYLE_COND_NOT_BEGINS_WITH_STR:
 		negate = TRUE;  /* ...and fall through */
 	case GNM_STYLE_COND_BEGINS_WITH_STR:
-		res = (cv &&
-		       g_str_has_prefix (value_peek_string (cv),
-					 value_peek_string (val0)));
+		res = (cv && case_insensitive_has_fix (cv, val0, TRUE));
 		break;
 
 	case GNM_STYLE_COND_NOT_ENDS_WITH_STR:
 		negate = TRUE;  /* ...and fall through */
 	case GNM_STYLE_COND_ENDS_WITH_STR:
-		res = (cv &&
-		       g_str_has_suffix (value_peek_string (cv),
-					 value_peek_string (val0)));
+		res = (cv && case_insensitive_has_fix (cv, val0, FALSE));
 		break;
 
 	case GNM_STYLE_COND_CUSTOM:
