@@ -345,18 +345,30 @@ sub test_exporter {
 
     my $tmp1 = "$tmp.gnumeric";
     &junkfile ($tmp1) unless $keep;
-    $code = system ("$ssconvert '$file' '$tmp1' 2>&1 | sed -e 's/^/| /'");
-    &system_failure ($ssconvert, $code) if $code;
+    {
+	my $cmd = "$ssconvert '$file' '$tmp1'";
+	print STDERR "# $cmd\n" if $verbose;
+	my $code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
+	&system_failure ($ssconvert, $code) if $code;
+    }
 
     my $tmp2 = "$tmp-new.$ext";
     &junkfile ($tmp2) unless $keep;
-    $code = system ("$ssconvert '$file' '$tmp2' 2>&1 | sed -e 's/^/| /'");
-    &system_failure ($ssconvert, $code) if $code;
+    {
+	my $cmd = "$ssconvert '$file' '$tmp2'";
+	print STDERR "# $cmd\n" if $verbose;
+	my $code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
+	&system_failure ($ssconvert, $code) if $code;
+    }
 
     my $tmp3 = "$tmp-new.gnumeric";
     &junkfile ($tmp3) unless $keep;
-    $code = system ("$ssconvert '$tmp2' '$tmp3' 2>&1 | sed -e 's/^/| /'");
-    &system_failure ($ssconvert, $code) if $code;
+    {
+	my $cmd = "$ssconvert '$tmp2' '$tmp3'";
+	print STDERR "# $cmd\n" if $verbose;
+	my $code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
+	&system_failure ($ssconvert, $code) if $code;
+    }
 
     my $tmp4 = "$tmp.xml";
     &junkfile ($tmp4) unless $keep;
@@ -376,6 +388,38 @@ sub test_exporter {
 
 # -----------------------------------------------------------------------------
 
+# The BIFF formats leave us with a msole:codepage property
+my $drop_codepage_filter =
+    "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
+
+my $drop_generator_filter =
+    "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'";
+
+# BIFF7 doesn't store cell comment author
+my $no_author_filter = "$PERL -p -e 's{ Author=\"[^\"]*\"}{};'";
+
+# BIFF7 cannot store rich text comments
+my $no_rich_comment_filter = "$PERL -p -e 'if (/gnm:CellComment/) { s{ TextFormat=\"[^\"]*\"}{}; }'";
+
+# Excel cannot have superscript and subscript at the same time
+my $supersub_filter = "$PERL -p -e 's{\\[superscript=1:(\\d+):(\\d+)\\]\\[subscript=1:(\\d+):\\2\\]}{[superscript=1:\$1:\$3][subscript=1:\$3:\$2]};'";
+
+
+sub normalize_filter {
+    my ($f) = @_;
+    return 'cat' unless defined $f;
+
+    $f =~ s/std:drop_codepage/$drop_codepage_filter/;
+    $f =~ s/std:drop_generator/$drop_generator_filter/;
+    $f =~ s/std:no_author/$no_author_filter/;
+    $f =~ s/std:no_rich_comment/$no_rich_comment_filter/;
+    $f =~ s/std:supersub/$supersub_filter/;
+
+    return $f;
+}
+
+# -----------------------------------------------------------------------------
+
 sub test_roundtrip {
     my ($file,%named_args) = @_;
 
@@ -386,8 +430,10 @@ sub test_roundtrip {
     my $resize = $named_args{'resize'};
     my $ignore_failure = $named_args{'ignore_failure'};
 
-    my $filter1 = $named_args{'filter1'} || $named_args{'filter'} || 'cat';
-    my $filter2 = $named_args{'filter2'} || $named_args{'filter'} || 'cat';
+    my $filter1 = &normalize_filter ($named_args{'filter1'} ||
+				     $named_args{'filter'});
+    my $filter2 = &normalize_filter ($named_args{'filter2'} ||
+				     $named_args{'filter'});
 
     my $tmp = fileparse ($file);
     $tmp =~ s/\.([a-zA-Z0-9]+)$// or die "Must have extension for roundtrip test.";
@@ -404,6 +450,7 @@ sub test_roundtrip {
 	print STDERR "# $cmd\n" if $verbose;
 	$code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
 	&system_failure ($ssconvert, $code) if $code;
+	die "Failed to produce $file_resized\n" unless -r $file_resized;
 	&junkfile ($file_resized) unless $keep;
     }
     
@@ -415,6 +462,7 @@ sub test_roundtrip {
 	print "# $cmd\n" if $verbose;
 	my $code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
 	&system_failure ($ssconvert, $code) if $code;
+	die "Failed to produce $tmp1\n" unless -r $tmp1;
     }
 
     my $tmp2 = "$tmp-new.$ext";
@@ -425,6 +473,7 @@ sub test_roundtrip {
 	print "# $cmd\n" if $verbose;
 	my $code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
 	&system_failure ($ssconvert, $code) if $code;
+	die "Failed to produce $tmp2\n" unless -r $tmp2;
     }
 
     my $tmp_xml = "$tmp.xml";
