@@ -63,6 +63,7 @@ my @sources =
      "$samples/formula-tests.gnumeric",
      "$samples/graph-tests.gnumeric",
      "$samples/merge-tests.gnumeric",
+     "$samples/names-tests.gnumeric",
      "$samples/number-tests.gnumeric",
      "$samples/page-setup-tests.gnumeric",
      "$samples/rich-text-tests.gnumeric",
@@ -102,7 +103,7 @@ foreach my $src (@sources) {
     my %members;
     foreach (`$unzip -v $tmp`) {
 	next unless /^----/ ... /^----/;
-	next unless m{\s(\S+)$};
+	next unless m{^\s*\d.*\s(\S+)$};
 	my $member = $1;
 	if (exists $members{$member}) {
 	    print STDERR "Duplicate member $member\n";
