@@ -16,23 +16,21 @@ my $file = "$samples/colrow-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
-
-my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
+		 'filter2' => 'std:drop_generator');
 
 &message ("Check col/row info xls/BIFF7 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff7',
 		 'ext' => "xls",
 		 'resize' => '16384x256',
-		 'filter2' => $xls_codepage_filter,
+		 'filter2' => 'std:drop_codepage',
 		 'ignore_failure' => 1);
 
 &message ("Check col/row info xls/BIFF8 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff8',
 		 'ext' => "xls",
-		 'filter2' => $xls_codepage_filter,
+		 'filter2' => 'std:drop_codepage',
 		 'ignore_failure' => 1);
 
 &message ("Check col/row info xlsx roundtrip.");
