@@ -16,12 +16,7 @@ my $file = "$samples/cell-comment-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
-
-my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
-
-# BIFF7 cannot store comment author
-my $xls_no_author_filter = "$PERL -p -e 's{ Author=\"[^\"]*\"}{};'";
+		 'filter2' => 'std:drop_generator');
 
 my $xls_greek_filter = "$PERL -p -C7 -e '1 while (s{\\b(Text=\"Greek[ ?]+)[^ ?\"]}{\$1?})'";
 
@@ -30,14 +25,14 @@ my $xls_greek_filter = "$PERL -p -C7 -e '1 while (s{\\b(Text=\"Greek[ ?]+)[^ ?\"
 		 'format' => 'Gnumeric_Excel:excel_biff7',
 		 'ext' => "xls",
 		 'resize' => '16384x256',
-		 'filter1' => "$xls_greek_filter | $xls_no_author_filter",
-		 'filter2' => $xls_codepage_filter);
+		 'filter1' => "$xls_greek_filter | std:no_author",
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check cell-comment xls/BIFF8 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff8',
 		 'ext' => "xls",
-		 'filter2' => $xls_codepage_filter);
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check cell-comment xlsx roundtrip.");
 &test_roundtrip ($file,
