@@ -16,9 +16,7 @@ my $file = "$samples/auto-filter-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
-
-my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
+		 'filter2' => 'std:drop_generator');
 
 my $xls_greek_filter = "$PERL -p -C7 -e '1 while (s{\\b((Title|Message)=\".*Greek[ ?]+)[^ ?\"]}{\$1?})'";
 
@@ -28,13 +26,13 @@ my $xls_greek_filter = "$PERL -p -C7 -e '1 while (s{\\b((Title|Message)=\".*Gree
 		 'ext' => "xls",
 		 'resize' => '16384x256',
 		 'filter1' => $xls_greek_filter,
-		 'filter2' => $xls_codepage_filter);
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check auto-filter xls/BIFF8 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff8',
 		 'ext' => "xls",
-		 'filter2' => $xls_codepage_filter);
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check auto-filter xlsx roundtrip.");
 &test_roundtrip ($file,
