@@ -16,27 +16,20 @@ my $file = "$samples/cond-format-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
-
-my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
-
-# xls/biff cannot handle format in conditional formats.
-my $xls_cond_format_filter = "$PERL -p -e 'if (m{<gnm:Condition\\b} ... m{</gnm:Condition\\b}) { s{\\s+Format=\"[^\"\"]*\"}{}; }'";
+		 'filter2' => 'std:drop_generator');
 
 &message ("Check conditional format xls/BIFF7 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff7',
 		 'ext' => "xls",
 		 'resize' => '16384x256',
-		 # 'filter1' => $xls_cond_format_filter,
-		 'filter2' => $xls_codepage_filter);
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check conditional format xls/BIFF8 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff8',
 		 'ext' => "xls",
-		 '# filter1' => $xls_cond_format_filter,
-		 'filter2' => $xls_codepage_filter);
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check conditional format xlsx roundtrip.");
 &test_roundtrip ($file,
